@@ -106,7 +106,7 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
         if res or self.Get('os_install_root_type') in ('livecd','usb-hdd'):
             return res
         else:
-            return self.choice()[-1]
+            return "1024x768"
 
 class VariableOsInstallX11VideoAvailable(VideoVariable):
     """
